AntiBotDetector

Trait AntiBotDetector 

pub trait AntiBotDetector:
    Send
    + Sync
    + Debug
    + 'static {
    // Required method
    fn detect(&self, signals: &AntiBotSignals<'_>) -> Option<AntiBotTech>;
}
Detects anti-bot or web application firewall responses from response signals.

Required Methods

fn detect(&self, signals: &AntiBotSignals<'_>) -> Option<AntiBotTech>

Returns the detected technology, or None when evidence is insufficient.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors