pub struct MemoryLoadSignal { /* private fields */ }Expand description
Periodically samples used system memory against a configurable budget.
Implementations
Sourceimpl MemoryLoadSignal
impl MemoryLoadSignal
Sourcepub fn new(options: MemoryLoadSignalOptions) -> Self
pub fn new(options: MemoryLoadSignalOptions) -> Self
Creates a memory load signal with the supplied options.