#[non_exhaustive]pub struct MemoryLoadSignalOptions {
pub max_used_memory_ratio: f32,
pub memory_bytes: Option<u64>,
pub sample_interval: Duration,
}Expand description
Options for periodic system memory load sampling.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_used_memory_ratio: f32Maximum used memory fraction before the signal reports overload.
memory_bytes: Option<u64>Optional byte budget used instead of total system memory.
sample_interval: DurationInterval between memory usage samples. Values below 1 ms are clamped to 1 ms.