pub struct CrawlerHandle { /* private fields */ }Expand description
A cheaply cloned weak back-reference to a running crawler.
Implementations
Sourceimpl CrawlerHandle
impl CrawlerHandle
Sourcepub async fn add_requests(
&self,
reqs: impl IntoIterator<Item = Request> + Send,
) -> Result<BatchAddHandle, CrawlError>
pub async fn add_requests( &self, reqs: impl IntoIterator<Item = Request> + Send, ) -> Result<BatchAddHandle, CrawlError>
Adds requests to the crawler’s queue.
Sourcepub async fn add_requests_with_options(
&self,
reqs: impl IntoIterator<Item = Request> + Send,
options: AddOptions,
) -> Result<BatchAddHandle, CrawlError>
pub async fn add_requests_with_options( &self, reqs: impl IntoIterator<Item = Request> + Send, options: AddOptions, ) -> Result<BatchAddHandle, CrawlError>
Adds requests with explicit queue insertion options.
Sourcepub fn stats(&self) -> Option<StatisticsSnapshot>
pub fn stats(&self) -> Option<StatisticsSnapshot>
Returns a snapshot of live crawl statistics while the crawler exists.
Sourcepub fn autoscaler_snapshot(&self) -> Option<AutoscalerSnapshot>
pub fn autoscaler_snapshot(&self) -> Option<AutoscalerSnapshot>
Returns a snapshot of the concurrency scaler while the crawler exists.
Sourcepub fn events(&self) -> Option<EventStream>
pub fn events(&self) -> Option<EventStream>
Subscribes to control-plane crawler events while the crawler exists.
Sourcepub fn results(&self) -> Option<ResultStream>
pub fn results(&self) -> Option<ResultStream>
Subscribes to terminal request snapshots while the crawler exists.
Sourcepub fn request_queue(&self) -> Option<Arc<dyn RequestQueue>>
pub fn request_queue(&self) -> Option<Arc<dyn RequestQueue>>
Returns the crawler’s request queue while the crawler exists.
Sourcepub fn crawl_policy(&self) -> Option<Arc<CrawlPolicy>>
pub fn crawl_policy(&self) -> Option<Arc<CrawlPolicy>>
Returns the configured crawl policy while the crawler exists.