RequestEnv

Struct RequestEnv 

#[non_exhaustive]
pub struct RequestEnv<'a> { pub request: Arc<Request>, pub crawler: CrawlerHandle, pub events: &'a EventBus, pub overrides: AttemptOverrides, }
Per-attempt inputs supplied to CrawlerKind::execute.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
request: Arc<Request>

The request being executed.

crawler: CrawlerHandle

A weak back-reference to the running crawler.

events: &'a EventBus

The crawler’s event bus.

overrides: AttemptOverrides

Overrides carried from the previous attempt of this request.

Implementations

Source

impl<'a> RequestEnv<'a>

pub fn duplicate(&self) -> RequestEnv<'a>

Clones these per-attempt inputs so one attempt can try a second execution path (e.g. smart HTTP-first promotion re-executing through a browser kind). The struct is non-exhaustive, so only core can provide this.