#[non_exhaustive]pub struct FailedRequestContext {
pub request: Arc<Request>,
pub error: Arc<CrawlError>,
pub retry_count: u32,
}Expand description
Owned payload handed to the failure handler when a request permanently fails.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request: Arc<Request>The request that permanently failed.
error: Arc<CrawlError>The final error produced while processing the request.
retry_count: u32The number of retry attempts made before the permanent failure.
Implementations