HttpRequest

Struct HttpRequest 

#[non_exhaustive]
pub struct HttpRequest { pub url: Url, pub method: Method, pub headers: HeaderMap, pub body: Option<RequestBody>, pub cookie_jar: Option<Arc<CookieJar>>, pub proxy: Option<Url>, pub timeout: Option<Duration>, pub max_redirects: u32, pub use_header_generator: bool, pub session_token: Option<SessionToken>, }
A backend-independent HTTP request.

Fingerprint-aware clients can generate browser-like headers when requested and use the optional session token to keep those headers consistent across related requests.

Examples

use millipede_core::{http_client::HttpRequest, request::Method};
use url::Url;

let request = HttpRequest::new(Url::parse("https://example.com/")?)
    .method(Method::HEAD)
    .max_redirects(3);
assert_eq!(request.method, Method::HEAD);

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
url: Url

URL to request.

method: Method

HTTP method.

headers: HeaderMap

HTTP request headers.

body: Option<RequestBody>

Optional request body.

cookie_jar: Option<Arc<CookieJar>>

Optional cookie jar used for this request and its response.

proxy: Option<Url>

Optional proxy URL.

timeout: Option<Duration>

Optional request timeout.

max_redirects: u32

Maximum number of redirects to follow.

use_header_generator: bool

Whether the HTTP client should generate browser-like request headers.

session_token: Option<SessionToken>

Token used to keep generated headers consistent across a session.

Implementations

Source

impl HttpRequest

pub fn new(url: Url) -> Self

Creates a GET request with no headers, body, cookie jar, proxy, or timeout.

pub fn from_request(request: &Request) -> Self

Copies the HTTP-facing fields from a crawl request.

pub fn method(self, method: Method) -> Self

Sets the HTTP method.

pub fn headers(self, headers: HeaderMap) -> Self

Replaces the HTTP headers.

pub fn body(self, body: RequestBody) -> Self

Sets the request body.

pub fn cookie_jar(self, cookie_jar: Arc<CookieJar>) -> Self

Sets the cookie jar.

pub fn proxy(self, proxy: Url) -> Self

Sets the proxy URL.

pub fn timeout(self, timeout: Duration) -> Self

Sets the request timeout.

pub fn max_redirects(self, max_redirects: u32) -> Self

Sets the maximum number of redirects to follow.

pub fn use_header_generator(self, enabled: bool) -> Self

Enables or disables browser-like header generation.

pub fn session_token(self, token: SessionToken) -> Self

Sets the token used for consistent per-session header generation.