#[non_exhaustive]pub enum TransformResult {
Enqueue,
Skip {
reason: String,
},
}Expand description
The outcome of transforming a candidate request before enqueueing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Enqueue
Enqueue the candidate, including any mutations made by the transform.
Skip
Reject the candidate and report the supplied reason.