#[non_exhaustive]pub struct AttemptOverrides {
pub proxy_kind: Option<ProxyKind>,
pub user_agent_profile: Option<String>,
pub backoff: Option<Duration>,
}Expand description
Overrides carried to the next attempt of the same request.
Overrides live in engine memory keyed by request unique key and do not survive restarts.
Examples
use millipede_core::retry_strategy::AttemptOverrides;
use std::time::Duration;
let mut overrides = AttemptOverrides::default();
overrides.backoff = Some(Duration::from_millis(250));Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.proxy_kind: Option<ProxyKind>Proxy bucket requested for the next attempt.
user_agent_profile: Option<String>User-agent profile requested for the next attempt.
backoff: Option<Duration>Delay before the next attempt begins.