pub struct SitemapRequestList { /* private fields */ }Expand description
A lazy, streaming source of requests parsed from XML sitemaps.
Implementations
Sourceimpl SitemapRequestList
impl SitemapRequestList
Sourcepub async fn fetch_next(&self) -> Result<Option<Request>, CrawlError>
pub async fn fetch_next(&self) -> Result<Option<Request>, CrawlError>
Returns the next unique request, fetching sitemap documents only on demand.
Sourcepub async fn is_finished(&self) -> bool
pub async fn is_finished(&self) -> bool
Returns whether this list has permanently stopped producing requests.
Sourcepub async fn processed_count(&self) -> u64
pub async fn processed_count(&self) -> u64
Returns the number of requests emitted by this list.
Sourcepub async fn persist(&self) -> Result<(), CrawlError>
pub async fn persist(&self) -> Result<(), CrawlError>
Persists current progress, or does nothing when persistence is disabled.