pub struct RateLimitReportingClient { /* private fields */ }Expand description
A storage client wrapper that reports healthy and rate-limited operations to autoscaling.
Implementations
Sourceimpl RateLimitReportingClient
impl RateLimitReportingClient
Sourcepub fn new(
inner: Arc<dyn StorageClient>,
handle: ClientLoadSignalHandle,
) -> Arc<dyn StorageClient>
pub fn new( inner: Arc<dyn StorageClient>, handle: ClientLoadSignalHandle, ) -> Arc<dyn StorageClient>
Wraps inner with rate-limit reporting and returns it as a storage client.