#[non_exhaustive]pub struct ReclaimOptions {
pub forefront: bool,
pub increment_retry: bool,
}Expand description
Options controlling return of a leased request to the queue.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.forefront: boolWhether to reinsert at the front of the queue.
increment_retry: boolWhether to increment the request retry count.