Router

Struct Router 

pub struct Router<C> { /* private fields */ }
Routes request contexts by label and HTTP method.

Implementations

Source

impl<C: HasRequest + Send + 'static> Router<C>

pub fn new() -> Self

Creates an empty router.

pub fn route<H: RequestHandler<C>>( self, label: impl Into<String>, handler: H, ) -> Self

Adds a route that matches label with any HTTP method.

pub fn route_method<H: RequestHandler<C>>( self, label: impl Into<String>, method: Method, handler: H, ) -> Self

Adds a route that matches label with one HTTP method.

pub fn route_methods<H, I>( self, label: impl Into<String>, methods: I, handler: H, ) -> Self
where H: RequestHandler<C>, I: IntoIterator<Item = Method>,

Adds a route that matches label with any of the supplied HTTP methods.

pub fn default<H: RequestHandler<C>>(self, handler: H) -> Self

Sets the fallback handler used when no registered route matches.

pub fn middleware<M: Middleware<C>>(self, middleware: M) -> Self

Appends middleware that runs in registration order before a matched handler.